# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/media_files/media_file/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {

        "psr-4": {
            ... ,
            "MediaFiles\\MediaFile\\": "packages/media_files/media_file/src",
            "MediaFiles\\MediaFile\\Seeders\\": "packages/media_files/media_file/database/seeders"
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        MediaFiles\MediaFile\Providers\MediaFileServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'MediaFile'  => MediaFiles\MediaFile\Facades\MediaFile::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=MediaFiles\\MediaFile\\Seeders\\MediaFileTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="MediaFiles\MediaFile\Providers\MediaFileServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="MediaFiles\MediaFile\Providers\MediaFileServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="MediaFiles\MediaFile\Providers\MediaFileServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/media_file/{modulename}

**User**

    http://path-to-route-folder/user/media_file/{modulename}

**Public**

    http://path-to-route-folder/media_files


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/media_file/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/media_file/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/media_file/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/media_file/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/media_file/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/media_file/{modulename}/{slug}
    METHOD: GET