<?php

namespace MediaFiles\MediaFile\Providers;

use Illuminate\Support\ServiceProvider;
use MediaFiles\MediaFile\MediaFiles;

class MediaFileServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = true;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'media_file');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'media_file');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerFacade();
        // $this->registerCommands();

        $this->app->register(\MediaFiles\MediaFile\Providers\AuthServiceProvider::class);
        $this->app->register(\MediaFiles\MediaFile\Providers\RouteServiceProvider::class);
        // $this->app->register(\MediaFiles\MediaFile\Providers\EventServiceProvider::class);
        // $this->app->register(\MediaFiles\MediaFile\Providers\WorkflowServiceProvider::class);
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->bind('media_files.media_file', function($app)
        {
            return $this->app->make(MediaFiles::class);
        });
    }



    /**
     * Merges user's and media_file's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'media_files.media_file'
        );
        
        
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/file.php', 'media_files.media_file.file'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                \MediaFiles\MediaFile\Commands\MediaFile::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['media_files.media_file'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/' => config_path('media_files/media_file')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/media_file')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/media_file')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
